@@ -1,17 +1,19 @@
-"""Translation registry."""
+from typing import Dict
 
-from flufl.i18n._application import Application
 from public import public
 
+from flufl.i18n.types import TranslationStrategy
+from flufl.i18n._application import Application
+
 
 @public
 class Registry:
     """A registry of application translation lookup strategies."""
     def __init__(self):
         # Map application names to Application instances.
-        self._registry = {}
+        self._registry: Dict[str, Application] = {}
 
-    def register(self, strategy):
+    def register(self, strategy: TranslationStrategy) -> Application:
         """Add an association between an application and a lookup strategy.
 
         :param strategy: An application translation lookup strategy.
@@ -25,4 +27,5 @@ class Registry:
         return application
 
 
+registry: Registry                                  # for mypy
 public(registry=Registry())
