@@ -1,31 +1,33 @@
-"""Catalog search strategies."""
-
 import os
 import gettext
 
+from types import ModuleType
+from typing import Optional
+
 from public import public
 
+from flufl.i18n.types import TranslationStrategy
 
-class _BaseStrategy:
+
+class _BaseStrategy(TranslationStrategy):
     """Common code for strategies."""
 
-    def __init__(self, name):
+    def __init__(self, name: str):
         """Create a catalog lookup strategy.
 
         :param name: The application's name.
-        :type name: string
         """
-        self.name = name
-        self._messages_dir = None
+        self._name = name
+        self._messages_dir: str
 
-    def __call__(self, language_code=None):
+    def __call__(self,
+                 language_code: Optional[str] = None
+                 ) -> gettext.NullTranslations:
         """Find the catalog for the language.
 
         :param language_code: The language code to find.  If None, then the
             default gettext language code lookup scheme is used.
-        :type language_code: string
         :return: A `gettext` catalog.
-        :rtype: `gettext.NullTranslations` or subclass
         """
         # gettext.translation() requires None or a sequence.
         languages = (None if language_code is None else [language_code])
@@ -36,20 +38,23 @@ class _BaseStrategy:
             # Fall back to untranslated source language.
             return gettext.NullTranslations()
 
+    @property
+    def name(self) -> str:
+        """The application's name."""
+        return self._name
+
 
 @public
 class PackageStrategy(_BaseStrategy):
     """A strategy that finds catalogs based on package paths."""
 
-    def __init__(self, name, package):
+    def __init__(self, name: str, package: ModuleType):
         """Create a catalog lookup strategy.
 
         :param name: The application's name.
-        :type name: string
         :param package: The package path to the message catalogs.  This
             strategy uses the __file__ of the package path as the directory
             containing `gettext` messages.
-        :type package_name: module
         """
         super().__init__(name)
         self._messages_dir = os.path.dirname(package.__file__)
@@ -59,15 +64,10 @@ class PackageStrategy(_BaseStrategy):
 class SimpleStrategy(_BaseStrategy):
     """A simpler strategy for getting translations."""
 
-    def __init__(self, name):
+    def __init__(self, name: str):
         """Create a catalog lookup strategy.
 
         :param name: The application's name.
-        :type name: string
-        :param package: The package path to the message catalogs.  This
-            strategy uses the __file__ of the package path as the directory
-            containing `gettext` messages.
-        :type package_name: module
         """
         super().__init__(name)
-        self._messages_dir = os.environ.get('LOCPATH')
+        self._messages_dir = os.environ.get('LOCPATH', '')
