@@ -1,9 +1,8 @@
-"""Test for expand() coverage."""
+from unittest.mock import patch
 
-import unittest
+import pytest
 
 from flufl.i18n._expand import expand
-from unittest.mock import patch
 
 
 class FailingTemplateClass:
@@ -14,8 +13,8 @@ class FailingTemplateClass:
         raise TypeError
 
 
-class TestExpand(unittest.TestCase):
-    def test_exception(self):
-        with patch('flufl.i18n._expand.log.exception') as log:
+def test_exception():
+    with patch('flufl.i18n._expand.log.exception') as log:
+        with pytest.raises(TypeError):
             expand('my-template', {}, FailingTemplateClass)
-        log.assert_called_once_with('broken template: %s', 'my-template')
+    log.assert_called_once_with('broken template: %s', 'my-template')
